# *****************************************************************
#
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2018, 2019. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# *****************************************************************

from __future__ import print_function
import numpy as np
from scipy import sparse
from sklearn.datasets import dump_svmlight_file
from scipy import stats
import os

import argparse

defaultPath = os.getcwd()
CLI=argparse.ArgumentParser()
CLI.add_argument(
   "--data_path",
   type=str,
   default=defaultPath
)
CLI.add_argument(
   "--num_examples",
   type=int,
   default= 10000
)
args = CLI.parse_args()

## Generate Data

num_ex = args.num_examples
num_ft = 10000
density = 0.1

print('Generating data...', '10000x10000 with density=0.1')

X = sparse.random(num_ex, num_ft, density,format='csr', data_rvs=stats.uniform(1,0).rvs)
y = 2*np.random.randint(2, size=num_ex)-1

# print X[0]

from sklearn.preprocessing import normalize
X_norm = normalize(X, norm='l2', axis=1)

# print X_norm[0]

print('Data have been successfully generated!')

## Store data into different file formats

filename = args.data_path + "/data/data"

# Save data to libsvm format
print('Writing data to libsvm format...')
dump_svmlight_file(X_norm,y,filename+'.libsvm',zero_based=False)

# Save data to csv format
print('Converting data to dense representation...')
X_dense = np.array(X.todense())
csv_data = np.column_stack((y,X_dense))
print('Writing data to csv format...')
np.savetxt(filename + '.csv', csv_data, delimiter=',')

from snap_ml_spark.Utils import dump_to_snap_format
# Save data to snap dense format
print('Writing data to dense snap format...')
dump_to_snap_format(X_dense, y, filename+'_dense.snap')
print('Writing data to dense transpose snap format...')
dump_to_snap_format(X_dense, y, filename+'_dense.snap.t', transpose=True)
# Save data to snap sparse format
print('Writing data to sparse snap format...')
dump_to_snap_format(X, y, filename+'_sparse.snap')
print('Writing data to sparse transpose snap format...')
dump_to_snap_format(X, y, filename+'_sparse.snap.t', transpose=True)
# Save data to snap l2 format
dump_to_snap_format(X, y, filename+'_l2.snap', implicit_vals=True)
